@@ -84,7 +84,7 @@ QString ConfiguredFromProjectItemEntry()
 }
 }
 
-typedef QPair<QString, IProject*> Target;
+using Target = QPair<QString, IProject*>;
 Q_DECLARE_METATYPE(Target)
 
 
@@ -185,33 +185,32 @@ public:
         //qCDebug(SHELL) << "got mode and type:" << type << type->id() << mode << mode->id();
         if( type && mode )
         {
-            ILauncher* launcher = nullptr;
-            foreach (ILauncher *l, type->launchers())
-            {
+            const auto launchers = type->launchers();
+            auto it = std::find_if(launchers.begin(), launchers.end(), [&](ILauncher* l) {
                 //qCDebug(SHELL) << "available launcher" << l << l->id() << l->supportedModes();
-                if (l->supportedModes().contains(mode->id())) {
-                    launcher = l;
-                    break;
-                }
-            }
-            if (launcher)
-            {
+                return (l->supportedModes().contains(mode->id()));
+            });
+            if (it != launchers.end()) {
+                ILauncher* launcher = *it;
+
                 QStringList itemPath = Core::self()->projectController()->projectModel()->pathFromIndex(contextItem->index());
-                ILaunchConfiguration* ilaunch = nullptr;
-                foreach (LaunchConfiguration *l, launchConfigurations) {
+                auto it = std::find_if(launchConfigurations.constBegin(), launchConfigurations.constEnd(),
+                                       [&] (LaunchConfiguration* l) {
                     QStringList path = l->config().readEntry(Strings::ConfiguredFromProjectItemEntry(), QStringList());
                     if (l->type() == type && path == itemPath) {
                         qCDebug(SHELL) << "already generated ilaunch" << path;
-                        ilaunch = l;
-                        break;
+                        return true;
                     }
-                }
+                    return false;
+                });
+                ILaunchConfiguration* ilaunch = (it != launchConfigurations.constEnd()) ? *it : nullptr;
+
                 if (!ilaunch) {
                     ilaunch = q->createLaunchConfiguration( type,
                                                             qMakePair( mode->id(), launcher->id() ),
                                                             contextItem->project(),
                                                             contextItem->text() );
-                    LaunchConfiguration* launch = static_cast<LaunchConfiguration*>(ilaunch);
+                    auto* launch = static_cast<LaunchConfiguration*>(ilaunch);
                     type->configureLaunchFromItem( launch->config(), contextItem );
                     launch->config().writeEntry(Strings::ConfiguredFromProjectItemEntry(), itemPath);
                     //qCDebug(SHELL) << "created config, launching";
@@ -243,8 +242,8 @@ public:
 
         if( l && ( ( !currentLaunchProject.isEmpty() && ( !l->project() || l->project()->name() != currentLaunchProject ) ) || l->configGroupName() != currentLaunchName ) )
         {
-            foreach( QAction* a, currentTargetAction->actions() )
-            {
+            const auto actions = currentTargetAction->actions();
+            for (QAction* a : actions) {
                 LaunchConfiguration* l = static_cast<LaunchConfiguration*>( qvariant_cast<void*>( a->data() ) );
                 if( currentLaunchName == l->configGroupName()
                     && ( ( currentLaunchProject.isEmpty() && !l->project() )
@@ -303,8 +302,10 @@ public:
 
 RunController::RunController(QObject *parent)
     : IRunController(parent)
-    , d(new RunControllerPrivate)
+    , d_ptr(new RunControllerPrivate)
 {
+    Q_D(RunController);
+
     setObjectName(QStringLiteral("RunController"));
 
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/kdevelop/RunController"),
@@ -335,8 +336,10 @@ RunController::~RunController() = default;
 
 void KDevelop::RunController::launchChanged( LaunchConfiguration* l )
 {
-    foreach( QAction* a, d->currentTargetAction->actions() )
-    {
+    Q_D(RunController);
+
+    const auto actions = d->currentTargetAction->actions();
+    for (QAction* a : actions) {
         if( static_cast<LaunchConfiguration*>( a->data().value<void*>() ) == l )
         {
             a->setText( d->launchActionText( l ) );
@@ -347,6 +350,8 @@ void KDevelop::RunController::launchChanged( LaunchConfiguration* l )
 
 void RunController::cleanup()
 {
+    Q_D(RunController);
+
     delete d->executeMode;
     d->executeMode = nullptr;
     delete d->profileMode;
@@ -360,6 +365,8 @@ void RunController::cleanup()
 
 void RunController::initialize()
 {
+    Q_D(RunController);
+
     d->executeMode = new ExecuteMode();
     addLaunchMode( d->executeMode );
     d->profileMode = new ProfileMode();
@@ -368,7 +375,8 @@ void RunController::initialize()
     addLaunchMode( d->debugMode );
     d->readLaunchConfigs( Core::self()->activeSession()->config(), nullptr );
 
-    foreach (IProject* project, Core::self()->projectController()->projects()) {
+    const auto projects = Core::self()->projectController()->projects();
+    for (IProject* project : projects) {
         slotProjectOpened(project);
     }
     connect(Core::self()->projectController(), &IProjectController::projectOpened,
@@ -392,7 +400,7 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
         qCDebug(SHELL) << "execute called without launch config!";
         return nullptr;
     }
-    LaunchConfiguration* run = static_cast<LaunchConfiguration*>(launch);
+    auto* run = static_cast<LaunchConfiguration*>(launch);
     //TODO: Port to launch framework, probably needs to be part of the launcher
     //if(!run.dependencies().isEmpty())
     //    ICore::self()->documentController()->saveAllDocuments(IDocument::Silent);
@@ -423,6 +431,8 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
 
 void RunController::setupActions()
 {
+    Q_D(RunController);
+
     QAction* action;
 
     // TODO not multi-window friendly, FIXME
@@ -490,20 +500,27 @@ void RunController::setupActions()
 
 LaunchConfigurationType* RunController::launchConfigurationTypeForId( const QString& id )
 {
+    Q_D(RunController);
+
     return d->launchConfigurationTypeForId( id );
 }
 
 void KDevelop::RunController::slotProjectOpened(KDevelop::IProject * project)
 {
+    Q_D(RunController);
+
     d->readLaunchConfigs( project->projectConfiguration(), project );
     d->updateCurrentLaunchAction();
 }
 
 void KDevelop::RunController::slotProjectClosing(KDevelop::IProject * project)
 {
+    Q_D(RunController);
+
     if (!d->currentTargetAction) return;
 
-    foreach (QAction* action, d->currentTargetAction->actions()) {
+    const auto actions = d->currentTargetAction->actions();
+    for (QAction* action : actions) {
         LaunchConfiguration* l = static_cast<LaunchConfiguration*>(qvariant_cast<void*>(action->data()));
         if ( project == l->project() ) {
             l->save();
@@ -525,6 +542,8 @@ void KDevelop::RunController::slotRefreshProject(KDevelop::IProject* project)
 
 void RunController::slotDebug()
 {
+    Q_D(RunController);
+
     if (d->launchConfigurations.isEmpty()) {
         showConfigurationDialog();
     }
@@ -536,6 +555,8 @@ void RunController::slotDebug()
 
 void RunController::slotProfile()
 {
+    Q_D(RunController);
+
     if (d->launchConfigurations.isEmpty()) {
         showConfigurationDialog();
     }
@@ -547,6 +568,8 @@ void RunController::slotProfile()
 
 void RunController::slotExecute()
 {
+    Q_D(RunController);
+
     if (d->launchConfigurations.isEmpty()) {
         showConfigurationDialog();
     }
@@ -564,6 +587,8 @@ void KDevelop::RunController::showConfigurationDialog() const
 
 LaunchConfiguration* KDevelop::RunController::defaultLaunch() const
 {
+    Q_D(const RunController);
+
     QAction* projectAction = d->currentTargetAction->currentAction();
     if( projectAction )
         return static_cast<LaunchConfiguration*>(qvariant_cast<void*>(projectAction->data()));
@@ -572,6 +597,8 @@ LaunchConfiguration* KDevelop::RunController::defaultLaunch() const
 
 void KDevelop::RunController::registerJob(KJob * job)
 {
+    Q_D(RunController);
+
     if (!job)
         return;
 
@@ -596,7 +623,7 @@ void KDevelop::RunController::registerJob(KJob * job)
         connect( job, &KJob::finished, this, &RunController::finished );
         connect( job, &KJob::destroyed, this, &RunController::jobDestroyed );
 
-        // FIXME percent is a private signal and thus we cannot use new connext syntax
+        // FIXME percent is a private signal and thus we cannot use new connect syntax
         connect(job, SIGNAL(percent(KJob*,ulong)), this, SLOT(jobPercentChanged()));
 
         IRunController::registerJob(job);
@@ -611,6 +638,8 @@ void KDevelop::RunController::registerJob(KJob * job)
 
 void KDevelop::RunController::unregisterJob(KJob * job)
 {
+    Q_D(RunController);
+
     IRunController::unregisterJob(job);
 
     Q_ASSERT(d->jobs.contains(job));
@@ -627,6 +656,8 @@ void KDevelop::RunController::unregisterJob(KJob * job)
 
 void KDevelop::RunController::checkState()
 {
+    Q_D(RunController);
+
     bool running = false;
 
     int jobCount = 0;
@@ -663,10 +694,12 @@ void KDevelop::RunController::checkState()
 
 void KDevelop::RunController::stopAllProcesses()
 {
+    Q_D(RunController);
+
     // composite jobs might remove child jobs, see also:
     // https://bugs.kde.org/show_bug.cgi?id=258904
-    // foreach already iterates over a copy
-    foreach (KJob* job, d->jobs.keys()) {
+    const auto jobs = d->jobs.keys();
+    for (KJob* job : jobs) {
         // now we check the real list whether it was deleted
         if (!d->jobs.contains(job))
             continue;
@@ -680,7 +713,7 @@ void KDevelop::RunController::stopAllProcesses()
 
 void KDevelop::RunController::slotKillJob()
 {
-    QAction* action = dynamic_cast<QAction*>(sender());
+    auto* action = qobject_cast<QAction*>(sender());
     Q_ASSERT(action);
 
     KJob* job = static_cast<KJob*>(qvariant_cast<void*>(action->data()));
@@ -717,6 +750,8 @@ void KDevelop::RunController::finished(KJob * job)
 
 void RunController::jobDestroyed(QObject* job)
 {
+    Q_D(RunController);
+
     KJob* kjob = static_cast<KJob*>(job);
     if (d->jobs.contains(kjob)) {
         qCWarning(SHELL) << "job destroyed without emitting finished signal!";
@@ -745,6 +780,8 @@ void KDevelop::RunController::resumed(KJob * job)
 
 QList< KJob * > KDevelop::RunController::currentJobs() const
 {
+    Q_D(const RunController);
+
     return d->jobs.keys();
 }
 
@@ -761,16 +798,22 @@ QList<ILaunchConfiguration*> RunController::launchConfigurations() const
 
 QList<LaunchConfiguration*> RunController::launchConfigurationsInternal() const
 {
+    Q_D(const RunController);
+
     return d->launchConfigurations;
 }
 
 QList<LaunchConfigurationType*> RunController::launchConfigurationTypes() const
 {
+    Q_D(const RunController);
+
     return d->launchConfigurationTypes.values();
 }
 
 void RunController::addConfigurationType( LaunchConfigurationType* type )
 {
+    Q_D(RunController);
+
     if( !d->launchConfigurationTypes.contains( type->id() ) )
     {
         d->launchConfigurationTypes.insert( type->id(), type );
@@ -779,8 +822,10 @@ void RunController::addConfigurationType( LaunchConfigurationType* type )
 
 void RunController::removeConfigurationType( LaunchConfigurationType* type )
 {
-    foreach( LaunchConfiguration* l, d->launchConfigurations )
-    {
+    Q_D(RunController);
+
+    const auto oldLaunchConfigurations = d->launchConfigurations;
+    for (LaunchConfiguration* l : oldLaunchConfigurations) {
         if( l->type() == type )
         {
             removeLaunchConfigurationInternal( l );
@@ -791,6 +836,8 @@ void RunController::removeConfigurationType( LaunchConfigurationType* type )
 
 void KDevelop::RunController::addLaunchMode(KDevelop::ILaunchMode* mode)
 {
+    Q_D(RunController);
+
     if( !d->launchModes.contains( mode->id() ) )
     {
         d->launchModes.insert( mode->id(), mode );
@@ -799,17 +846,23 @@ void KDevelop::RunController::addLaunchMode(KDevelop::ILaunchMode* mode)
 
 QList< KDevelop::ILaunchMode* > KDevelop::RunController::launchModes() const
 {
+    Q_D(const RunController);
+
     return d->launchModes.values();
 }
 
 void KDevelop::RunController::removeLaunchMode(KDevelop::ILaunchMode* mode)
 {
+    Q_D(RunController);
+
     d->launchModes.remove( mode->id() );
 }
 
 KDevelop::ILaunchMode* KDevelop::RunController::launchModeForId(const QString& id) const
 {
-    QMap<QString,ILaunchMode*>::iterator it = d->launchModes.find( id );
+    Q_D(const RunController);
+
+    auto it = d->launchModes.find( id );
     if( it != d->launchModes.end() )
     {
         return it.value();
@@ -819,6 +872,8 @@ KDevelop::ILaunchMode* KDevelop::RunController::launchModeForId(const QString& i
 
 void KDevelop::RunController::addLaunchConfiguration(KDevelop::LaunchConfiguration* l)
 {
+    Q_D(RunController);
+
     if( !d->launchConfigurations.contains( l ) )
     {
         d->addLaunchAction( l );
@@ -853,7 +908,10 @@ void KDevelop::RunController::removeLaunchConfiguration(KDevelop::LaunchConfigur
 
 void RunController::removeLaunchConfigurationInternal(LaunchConfiguration *l)
 {
-    foreach( QAction* a, d->currentTargetAction->actions() ) {
+    Q_D(RunController);
+
+    const auto actions = d->currentTargetAction->actions();
+    for (QAction* a : actions) {
         if( static_cast<LaunchConfiguration*>( a->data().value<void*>() ) == l ) {
             bool wasSelected = a->isChecked();
             d->currentTargetAction->removeAction( a );
@@ -880,8 +938,10 @@ void KDevelop::RunController::executeDefaultLaunch(const QString& runMode)
 
 void RunController::setDefaultLaunch(ILaunchConfiguration* l)
 {
-    foreach( QAction* a, d->currentTargetAction->actions() )
-    {
+    Q_D(RunController);
+
+    const auto actions = d->currentTargetAction->actions();
+    for (QAction* a : actions) {
         if( static_cast<ILaunchConfiguration*>( a->data().value<void*>() ) == l )
         {
             a->setChecked(true);
@@ -892,11 +952,11 @@ void RunController::setDefaultLaunch(ILaunchConfiguration* l)
 
 bool launcherNameExists(const QString& name)
 {
-    foreach(ILaunchConfiguration* config, Core::self()->runControllerInternal()->launchConfigurations()) {
-        if(config->name()==name)
-            return true;
-    }
-    return false;
+    const auto configs = Core::self()->runControllerInternal()->launchConfigurations();
+
+    return std::any_of(configs.begin(), configs.end(), [&](ILaunchConfiguration* config) {
+        return (config->name() == name);
+    });
 }
 
 QString makeUnique(const QString& name)
@@ -948,7 +1008,7 @@ ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigura
     configs << groupName;
     launchGroup.writeEntry( Strings::LaunchConfigurationsListEntry(), configs );
     launchGroup.sync();
-    LaunchConfiguration* l = new LaunchConfiguration( launchConfigGroup, project );
+    auto* l = new LaunchConfiguration( launchConfigGroup, project );
     l->setLauncherForMode( launcher.first, launcher.second );
     Core::self()->runControllerInternal()->addLaunchConfiguration( l );
     return l;
@@ -956,28 +1016,31 @@ ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigura
 
 QItemDelegate * KDevelop::RunController::delegate() const
 {
+    Q_D(const RunController);
+
     return d->delegate;
 }
 
 ContextMenuExtension RunController::contextMenuExtension(Context* ctx, QWidget* parent)
 {
+    Q_D(RunController);
+
     d->launchAsInfo.clear();
     d->contextItem = nullptr;
     ContextMenuExtension ext;
     if( ctx->type() == Context::ProjectItemContext ) {
-        KDevelop::ProjectItemContext* prjctx = static_cast<KDevelop::ProjectItemContext*>(ctx);
+        auto* prjctx = static_cast<KDevelop::ProjectItemContext*>(ctx);
         if( prjctx->items().count() == 1 )
         {
             ProjectBaseItem* itm = prjctx->items().at( 0 );
             int i = 0;
-            foreach( ILaunchMode* mode, d->launchModes )
-            {
+            for (ILaunchMode* mode : qAsConst(d->launchModes)) {
                 KActionMenu* menu = new KActionMenu(i18n("%1 As...", mode->name() ), parent);
-                foreach( LaunchConfigurationType* type, launchConfigurationTypes() )
-                {
+                const auto types = launchConfigurationTypes();
+                for (LaunchConfigurationType* type : types) {
                     bool hasLauncher = false;
-                    foreach( ILauncher* launcher, type->launchers() )
-                    {
+                    const auto launchers = type->launchers();
+                    for (ILauncher* launcher : launchers) {
                         if( launcher->supportedModes().contains( mode->id() ) )
                         {
                             hasLauncher = true;
@@ -986,10 +1049,11 @@ ContextMenuExtension RunController::contextMenuExtension(Context* ctx, QWidget*
                     if( hasLauncher && type->canLaunch(itm) )
                     {
                         d->launchAsInfo[i] = qMakePair( type->id(), mode->id() );
-                        QAction* act = new QAction(menu);
+                        auto* act = new QAction(menu);
                         act->setText( type->name() );
                         qCDebug(SHELL) << "Connect " << i << "for action" << act->text() << "in mode" << mode->name();
-                        connect( act, &QAction::triggered, this, [this, i] () { d->launchAs(i); } );
+                        connect(act, &QAction::triggered,
+                                this, [this, i] () { Q_D(RunController); d->launchAs(i); } );
                         menu->addAction(act);
                         i++;
                     }
